@@ -82,10 +82,10 @@ typedef struct nv_ioctl_card_info
 {
     NvU16    flags;               /* see below                   */
     NvU32    domain;              /* PCI domain number           */
-    NvU8     bus;                 /* bus number (PCI, AGP, etc)  */
-    NvU8     slot;                /* card slot                   */
-    NvU16    vendor_id;           /* PCI vendor id               */
-    NvU16    device_id;
+    NvU8     bus;                 /* PCI bus number              */
+    NvU8     slot;                /* PCI slot number             */
+    NvU16    vendor_id;           /* PCI vendor ID               */
+    NvU16    device_id;           /* PCI device ID               */
     NvU32    gpu_id;
     NvU16    interrupt_line;
     NvU64    reg_address    NV_ALIGN_BYTES(8);
@@ -203,6 +203,8 @@ typedef union
 #define NVRM_PCICFG_BAR_MEMTYPE_64BIT   0x00000004
 #define NVRM_PCICFG_BAR_ADDR_MASK       0xfffffff0
 
+#define NVRM_PCICFG_NUM_DWORDS          64
+
 #define NV_GPU_NUM_BARS                 3
 #define NV_GPU_BAR_INDEX_REGS           0
 #define NV_GPU_BAR_INDEX_FB             1
@@ -216,7 +218,6 @@ typedef struct
     NvU32 offset;
     NvU32 *map;
     nv_phwreg_t map_u;
-    NvS32 arch_phys_wc_add_token;
 } nv_aperture_t;
 
 typedef struct
@@ -283,19 +284,15 @@ typedef struct
     NvU32 gpu_id;
     void *handle;
 
-    NvU32 pci_cfg_space[16];
+    NvU32 pci_cfg_space[NVRM_PCICFG_NUM_DWORDS];
 
     /* physical characteristics */
     nv_aperture_t bars[NV_GPU_NUM_BARS];
     nv_aperture_t *regs;
     nv_aperture_t *fb, ud;
-    nv_aperture_t agp;
 
     NvU32  interrupt_line;
 
-    NvU32 agp_config;
-    NvU32 agp_status;
-
     NvU32 primary_vga;
 
     NvU32 sim_env;
@@ -339,22 +336,11 @@ typedef struct
 #define NV_FLAG_GVI_INTR_EN            0x0400
 #define NV_FLAG_PERSISTENT_SW_STATE    0x0800
 #define NV_FLAG_IN_RECOVERY            0x1000
+#define NV_FLAG_SKIP_CFG_CHECK         0x2000
 
-#define NV_PM_APM_SUSPEND       0x0001
-#define NV_PM_APM_RESUME        0x0002
-#define NV_PM_ACPI_HIBERNATE    0x0003
-#define NV_PM_ACPI_STANDBY      0x0004
-#define NV_PM_ACPI_RESUME       0x0005
-
-#define NV_AGP_STATUS_DISABLED  0x0000
-#define NV_AGP_STATUS_ENABLED   0x0001
-#define NV_AGP_STATUS_FAILED    0x0002
-
-#define NV_AGP_ENABLED(nv)      ((nv)->agp_status & NV_AGP_STATUS_ENABLED)
-#define NV_AGP_FAILED(nv)       ((nv)->agp_status & NV_AGP_STATUS_FAILED)
-
-#define NV_NVAGP_ENABLED(nv)    ((nv)->agp_config & NVOS_AGP_CONFIG_NVAGP)
-#define NV_OSAGP_ENABLED(nv)    ((nv)->agp_config & NVOS_AGP_CONFIG_OSAGP)
+#define NV_PM_ACPI_HIBERNATE    0x0001
+#define NV_PM_ACPI_STANDBY      0x0002
+#define NV_PM_ACPI_RESUME       0x0003
 
 #define NV_PRIMARY_VGA(nv)      ((nv)->primary_vga)
 
@@ -436,26 +422,6 @@ typedef struct
     ((offset) >= (nv)->ud.address) &&                                           \
     (((offset) + ((length)-1)) <= (nv)->ud.address + ((nv)->ud.size-1)))
 
-#define IS_AGP_OFFSET(nv, offset, length)                                       \
-    ((NV_AGP_ENABLED(nv)) &&                                                    \
-    ((offset) >= (nv)->agp.address) &&                                          \
-    (((offset) + ((length)-1)) <= (nv)->agp.address + ((nv)->agp.size-1)))
-
-/* duplicated from nvos.h for external builds */
-#ifndef NVOS_AGP_CONFIG_DISABLE_AGP
-#  define NVOS_AGP_CONFIG_DISABLE_AGP (0x00000000)
-#endif
-#ifndef NVOS_AGP_CONFIG_NVAGP
-#  define NVOS_AGP_CONFIG_NVAGP       (0x00000001)
-#endif
-#ifndef NVOS_AGP_CONFIG_OSAGP
-#  define NVOS_AGP_CONFIG_OSAGP       (0x00000002)
-#endif
-#ifndef NVOS_AGP_CONFIG_ANYAGP
-#  define NVOS_AGP_CONFIG_ANYAGP      (0x00000003)
-#endif
-
-
 /* device name length; must be atleast 8 */
 
 #define NV_DEVICE_NAME_LENGTH 40
@@ -538,17 +504,14 @@ void*  NV_API_CALL  nv_get_adapter_state         (NvU32, NvU16, NvU16);
 void   NV_API_CALL  nv_set_dma_address_size      (nv_state_t *, NvU32 );
 
 RM_STATUS  NV_API_CALL  nv_alias_pages           (nv_state_t *, NvU32, NvU32, NvU32, NvU64, NvU64 *, void **);
-RM_STATUS  NV_API_CALL  nv_alloc_pages           (nv_state_t *, NvU32, NvBool, NvBool, NvU32, NvBool, NvU64 *, void **);
-RM_STATUS  NV_API_CALL  nv_free_pages            (nv_state_t *, NvU32, NvU32, NvU32, NvU32, void *);
+RM_STATUS  NV_API_CALL  nv_alloc_pages           (nv_state_t *, NvU32, NvBool, NvU32, NvBool, NvU64 *, void **);
+RM_STATUS  NV_API_CALL  nv_free_pages            (nv_state_t *, NvU32, NvBool, NvU32, void *);
 RM_STATUS  NV_API_CALL  nv_guest_pfn_list        (nv_state_t *, unsigned int, unsigned int, unsigned int, unsigned int*);
 
-RM_STATUS  NV_API_CALL  nv_agp_init              (nv_state_t *, NvU64 *, NvU64 *, NvU32);
-RM_STATUS  NV_API_CALL  nv_agp_teardown          (nv_state_t *);
-
 NvS32  NV_API_CALL  nv_start_rc_timer            (nv_state_t *);
 NvS32  NV_API_CALL  nv_stop_rc_timer             (nv_state_t *);
 
-void   NV_API_CALL  nv_post_event                (nv_state_t *, nv_event_t *, NvU32, NvU32);
+void   NV_API_CALL  nv_post_event                (nv_state_t *, nv_event_t *, NvU32, NvU32, NvBool);
 NvS32  NV_API_CALL  nv_get_event                 (nv_state_t *, void *, nv_event_t *, NvU32 *);
 
 NvS32  NV_API_CALL  nv_no_incoherent_mappings    (void);
@@ -564,12 +527,24 @@ void   NV_API_CALL  nv_acpi_methods_uninit       (void);
 RM_STATUS  NV_API_CALL  nv_acpi_method           (NvU32, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
 RM_STATUS  NV_API_CALL  nv_acpi_dsm_method       (nv_state_t *, NvU8 *, NvU32, NvU32, void *, NvU16, NvU32 *, void *, NvU16 *);
 RM_STATUS  NV_API_CALL  nv_acpi_ddc_method       (nv_state_t *, void *, NvU32 *);
-void*  NV_API_CALL  nv_get_smu_state             (void);
+RM_STATUS  NV_API_CALL  nv_acpi_dod_method       (nv_state_t *, NvU32 *, NvU32 *);
+void*      NV_API_CALL  nv_get_smu_state         (void);
 RM_STATUS  NV_API_CALL  nv_lock_user_pages       (nv_state_t *, void *, NvU64, NvU64 *, void **);
 RM_STATUS  NV_API_CALL  nv_unlock_user_pages     (nv_state_t *, NvU64, NvU64 *, void *);
 RM_STATUS  NV_API_CALL  nv_acpi_rom_method       (nv_state_t *, NvU32 *, NvU32 *);
 RM_STATUS  NV_API_CALL  nv_log_error             (nv_state_t *, NvU32, const char *, va_list);
 
+#if defined(NV_MOBILE_DGPU)
+RM_STATUS  NV_API_CALL  nv_nvmap_create_client   (void);
+void       NV_API_CALL  nv_nvmap_destroy_client  (void);
+void       NV_API_CALL  nv_nvmap_free_handle_id  (NvU32);
+RM_STATUS  NV_API_CALL  nv_nvmap_dup_handle_id   (NvU32 *, NvU32);
+RM_STATUS  NV_API_CALL  nv_nvmap_get_page_list_info (NvU32, NvU32 *, NvU32 *, NvU32 *, BOOL *, NvU32 *);
+RM_STATUS  NV_API_CALL  nv_nvmap_get_page_list   (nv_state_t *, void *, NvU64, NvU64 *, void **, NvU32);
+RM_STATUS  NV_API_CALL  nv_nvmap_release_pages   (nv_state_t *, NvU64, NvU64 *, void *, NvU32);
+#endif
+RM_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
+
 /*
  * ---------------------------------------------------------------------------
  *
@@ -586,7 +561,6 @@ BOOL       NV_API_CALL  rm_init_adapter          (nv_stack_t *, nv_state_t *);
 BOOL       NV_API_CALL  rm_disable_adapter       (nv_stack_t *, nv_state_t *);
 BOOL       NV_API_CALL  rm_shutdown_adapter      (nv_stack_t *, nv_state_t *);
 RM_STATUS  NV_API_CALL  rm_validate_mmap_request (nv_stack_t *, nv_state_t *, NvU64, NvU64, NvU32 *);
-void       NV_API_CALL  rm_set_interrupts        (nv_stack_t *, BOOL);
 RM_STATUS  NV_API_CALL  rm_ioctl                 (nv_stack_t *, nv_state_t *, void *, NvU32, void *, NvU32);
 BOOL       NV_API_CALL  rm_isr                   (nv_stack_t *, nv_state_t *, NvU32 *);
 void       NV_API_CALL  rm_isr_bh                (nv_stack_t *, nv_state_t *);
@@ -596,18 +570,6 @@ RM_STATUS  NV_API_CALL  rm_get_vbios_version     (nv_stack_t *, nv_state_t *, Nv
 RM_STATUS  NV_API_CALL  rm_get_gpu_uuid          (nv_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
 void       NV_API_CALL  rm_free_unused_clients   (nv_stack_t *, nv_state_t *, void *);
 
-void       NV_API_CALL  rm_update_agp_config     (nv_stack_t *, nv_state_t *);
-RM_STATUS  NV_API_CALL  rm_init_agp              (nv_stack_t *, nv_state_t *, NvU64 *, NvU64 *);
-RM_STATUS  NV_API_CALL  rm_teardown_agp          (nv_stack_t *, nv_state_t *);
-
-RM_STATUS  NV_API_CALL  rm_alloc_agp_pages       (nv_stack_t *, nv_state_t *, NvU32, void **, NvU32 *);
-RM_STATUS  NV_API_CALL  rm_free_agp_pages        (nv_stack_t *, nv_state_t *, void *);
-
-RM_STATUS  NV_API_CALL  rm_alloc_agp_bitmap      (nv_stack_t *, nv_state_t *, NvU32, NvU32 *);
-RM_STATUS  NV_API_CALL  rm_free_agp_bitmap       (nv_stack_t *, nv_state_t *, NvU32, NvU32);
-RM_STATUS  NV_API_CALL  rm_set_agp_bitmap        (nv_stack_t *, nv_state_t *, void *);
-RM_STATUS  NV_API_CALL  rm_clear_agp_bitmap      (nv_stack_t *, nv_state_t *, void **);
-
 RM_STATUS  NV_API_CALL  rm_read_registry_dword   (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32 *);
 RM_STATUS  NV_API_CALL  rm_write_registry_dword  (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32);
 RM_STATUS  NV_API_CALL  rm_read_registry_binary  (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU8 *, NvU32 *);
@@ -624,7 +586,8 @@ void       NV_API_CALL  rm_register_compatible_ioctls   (nv_stack_t *);
 void       NV_API_CALL  rm_unregister_compatible_ioctls (nv_stack_t *);
 
 BOOL       NV_API_CALL  rm_is_legacy_device      (nv_stack_t *, NvU16, BOOL);
-BOOL       NV_API_CALL  rm_is_supported_device   (nv_stack_t *, nv_state_t *);
+BOOL       NV_API_CALL  rm_is_legacy_arch        (NvU32, NvU32);
+RM_STATUS  NV_API_CALL  rm_is_supported_device   (nv_stack_t *, nv_state_t *, NvU32 *, NvU32 *);
 
 
 void       NV_API_CALL  rm_check_pci_config_space (nv_stack_t *, nv_state_t *nv, BOOL, BOOL, BOOL);
@@ -648,9 +611,6 @@ RM_STATUS  NV_API_CALL  rm_p2p_destroy_mapping    (nv_stack_t *, NvU64);
 RM_STATUS  NV_API_CALL  rm_p2p_get_pages          (nv_stack_t *, NvU64, NvU32, NvU64, NvU64, NvU64 **, NvU32 **, NvU32 **, NvU32 *, void *, void (*)(void *), void *);
 RM_STATUS  NV_API_CALL  rm_p2p_put_pages          (nv_stack_t *, NvU64, NvU32, NvU64, void *);
 
-#define rm_disable_interrupts(sp) rm_set_interrupts((sp),FALSE)
-#define rm_enable_interrupts(sp)  rm_set_interrupts((sp),TRUE)
-
 #endif /* NVWATCH */
 
 #endif /* NVRM */
